@@ -1,5 +1,5 @@
 
-from cap.sortables import SortableTabularInline
+from suit.sortables import SortableTabularInline
 
 from suppliers.models import SupplierWarehouse
 
